@@ -6,7 +6,7 @@ import subprocess
 
 from django.contrib.sitemaps import ping_google
 from django.core.exceptions import ImproperlyConfigured
-from django.core.files import File 
+from django.core.files.base import ContentFile
 from django.core.files.storage import FileSystemStorage
 from django.core.paginator import EmptyPage, PageNotAnInteger
 from django.core.urlresolvers import reverse, NoReverseMatch
@@ -48,10 +48,7 @@ class SitemapGenerator(object):
         return url
 
     def _write(self, path, output):
-        buf = StringIO()
-        buf.write(output)
-        buf.seek(0)
-        self.storage.save(path, File(buf))
+        self.storage.save(path, ContentFile(output))
 
     def read_hash(self, path):
         with self.storage.open(path) as f:
@@ -173,7 +170,7 @@ class SitemapGenerator(object):
                     buf = StringIO()
                     with gzip.GzipFile(fileobj=buf, mode="w") as f:
                         f.write(output)
-                    self.storage.save(gzipped_path, File(buf))
+                    self.storage.save(gzipped_path, ContentFile(buf.getvalue()))
                 except OSError:
                     self.out("Compress %s file error" % path)
 
